package luna
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
Module LunaSource
checksum_digit s computes the Luhn check digit for the input string s. Returns the digit that would make s valid under the Luhn algorithm.
validate s validates whether the input string s is a valid Luhn number. Returns true if valid, false otherwise.